@@ -20,3 +20,9 @@ class InvalidFieldsParam(APIException):
     status_code = 422
     default_code = 'invalid_fields'
     default_detail = 'Invalid fields param, fields must be a list'
+
+
+class NotDataException(APIException):
+    status_code = 400
+    default_code = 'no data'
+    default_detail = 'no data ever'
