@@ -19,7 +19,9 @@ class BaseCredentialMixin(object):
     else:
         url = settings.DASHBOARD_URL + '/'
 
-    def get_user_info(self, request):
+    def get_user_info(
+        self, request, **kwargs
+    ):  # **kwargs for old versions compatibility
         if 'token' in request.GET and "platform_id" in request.GET:
             token = unquote(request.GET["token"])
         elif 'HTTP_AUTHORIZATION' in request.META and "platform_id" in request.GET:
