@@ -128,6 +128,7 @@ class BaseDataManager(object):
 
 class BaseStatisticSelector(object):
     selector_type: str = 'base'
+    default_path: str = '/tmp/'
 
     def __init__(
         self,
@@ -176,11 +177,15 @@ class BaseStatisticSelector(object):
     def generate_file_name(self, date_from: str, date_to: str) -> str:
         if self.values:
             hash_ = md5(str(self.values).encode('utf-8')).hexdigest()
-            filename = f'/tmp/{self.selector_type}_{self.admin}_{self.integration_id}_{hash_}{date_from}:{date_to}'
+            filename = f'{self.default_path}{self.selector_type}_{self.admin}_{self.integration_id}_{hash_}{date_from}:{date_to}'
         else:
-            filename = f'/tmp/{self.selector_type}_{self.admin}_{self.integration_id}_{date_from}:{date_to}'
+            filename = f'{self.default_path}{self.selector_type}_{self.admin}_{self.integration_id}_{date_from}:{date_to}'
         return filename
 
+    def generate_filename_hash(self, filename: str) -> str:
+        hash_ = md5(filename.encode('utf-8')).hexdigest()
+        return hash_
+
     def response(self) -> Response:
         date_from, date_to = self.get_date_params()
         filename = self.generate_file_name(date_from=date_from, date_to=date_to)
