@@ -81,7 +81,7 @@ def get_integration_info(
     if not token:
         token = get_smart_token(platform)
     config_url = f'{DASHBOARD_URL}api/get_config_url/?platform_id={platform}'
-    dash_response = requests.get(f'{config_url}?platform_id={platform}').json()
+    dash_response = requests.get(f'{config_url}').json()
     headers = {"Authorization": token}
     integration_url = f'{dash_response["config_url"]}{integration_id}/'
     integration = requests.get(integration_url, headers=headers).json()
