@@ -1,6 +1,7 @@
 import re
 from typing import Any
 from decimal import Decimal
+from typing import Optional
 from urllib.parse import urlparse, parse_qs
 
 UTM_PARAMS = [
@@ -12,6 +13,55 @@ UTM_PARAMS = [
     'utm_referrer',
 ]
 
+
+REGEX_PATTERN_VALUES = [
+    '"',
+    "'",
+    ';',
+    ',',
+    '==',
+    '!=',
+    '=@',
+    '!@',
+    '>',
+    '<',
+    '>=',
+    '<=',
+    '=^',
+    '!^',
+    '=\^',
+    '!\^',
+    '=$',
+    '!$',
+    '=\$',
+    '!\$',
+    '=~',
+    '!~',
+    '!=',
+    '==',
+    '!@',
+    '=@',
+    '<',
+    '>',
+    '<=',
+    '>=',
+    '!~',
+    '=~',
+    '!^',
+    '=^',
+    '!\^',
+    '=\^',
+    '!$',
+    '=$',
+    '!\$',
+    '=\$',
+    'undefined',
+    '\n',
+    '\t',
+    '\r',
+]
+
+
 __all__ = (
     'parse_utm',
     'get_operations',
@@ -20,9 +70,24 @@ __all__ = (
     'remove_tags',
     'replacer',
     'UTM_PARAMS',
+    'remove_unacceptable_chars',
+    'REGEX_PATTERN_VALUES',
 )
 
 
+def remove_unacceptable_chars(
+    value: Optional[str],
+    pattern_values: list = REGEX_PATTERN_VALUES,
+    default_value: Optional[str] = 'none',
+) -> str:
+    pattern = r'|'.join(f'{v}' for v in pattern_values)
+    if value is None or value == '':
+        return default_value
+    value = re.sub(pattern, ' ', str(value)).strip()
+    words = value.split()
+    return ' '.join(sorted(set(words), key=words.index))
+
+
 def parse_utm(url: str) -> dict:
     """
     :param url: str
@@ -101,3 +166,4 @@ def remove_tags(text: str) -> str:
     """
     TAG_RE = re.compile(r'<[^>]+>')
     return TAG_RE.sub('', text)
+
